@@ -10,4 +10,11 @@ def write(file_path, content):
 		with open(file_path, "w") as f:
 			return f.write(content)
 	except Exception as e:
-		return e
\ No newline at end of file
+		return e
+
+def create(file_path):
+	try:
+		with open(file_path, "x") as f:
+			return True
+	except Exception as e:
+		return e
